pub struct Nutation {
pub dpsi: Angle,
pub deps: Angle,
}Expand description
Nutation components with respect to some ecliptic of date.
Fields
dpsi: Angleδψ
deps: Angleδε
Implementations
Sourceimpl Nutation
impl Nutation
Sourcepub fn nutation_matrix(&self, epsa: MeanObliquity) -> DMat3
pub fn nutation_matrix(&self, epsa: MeanObliquity) -> DMat3
Builds the nutation rotation matrix from the mean obliquity of the ecliptic.