pub struct TimeBuilder<T>where
T: TimeScale,{ /* private fields */ }Expand description
TimeBuilder supports the construction of Time instances piecewise using the builder pattern.
Implementations
Sourceimpl<T> TimeBuilder<T>where
T: TimeScale,
impl<T> TimeBuilder<T>where
T: TimeScale,
Sourcepub fn new(scale: T) -> TimeBuilder<T>
pub fn new(scale: T) -> TimeBuilder<T>
Returns a new TimeBuilder, equivalent to a Time at J2000 in the given TimeScale.
Sourcepub fn with_ymd(self, year: i64, month: u8, day: u8) -> TimeBuilder<T>
pub fn with_ymd(self, year: i64, month: u8, day: u8) -> TimeBuilder<T>
Sets the year, month, and day of the Time under construction.
Sourcepub fn with_doy(self, year: i64, day_of_year: u16) -> TimeBuilder<T>
pub fn with_doy(self, year: i64, day_of_year: u16) -> TimeBuilder<T>
Sets the year and day_of_year of the Time under construction.