pub enum UtcError {
DateError(DateError),
TimeError(TimeOfDayError),
NonLeapSecondDate(Date),
UtcUndefined,
InvalidIsoString(String),
}Expand description
Error type returned when attempting to construct a Utc instance from invalid inputs.
Variants
DateError(DateError)
Invalid date component.
TimeError(TimeOfDayError)
Invalid time-of-day component.
NonLeapSecondDate(Date)
Second 60 was specified on a date without a leap second.
UtcUndefined
The UTC datetime could not be constructed (e.g. from a non-finite delta).
InvalidIsoString(String)
The input string is not valid ISO 8601.