ReferenceSystem

Enum ReferenceSystem 

pub enum ReferenceSystem {
    Iers1996,
    Iers2003(Iau2000Model),
    Iers2010,
}
Dynamic dispatch enum for IERS convention systems.

Variants



Iers1996

IERS 1996 conventions.



Iers2003(Iau2000Model)

IERS 2003 conventions with the given IAU 2000 model.



Iers2010

IERS 2010 conventions.

Implementations

Source

impl ReferenceSystem

pub fn earth_rotation( &self, tt: Time<Tt>, ut1: Time<Ut1>, corr: Corrections, ) -> DMat3

Returns the Earth rotation matrix for the given times and corrections.

pub fn greenwich_mean_sidereal_time( &self, tt: Time<Tt>, ut1: Time<Ut1>, ) -> GreenwichMeanSiderealTime

Computes Greenwich Mean Sidereal Time (GMST) for the active IERS convention.

pub fn greenwich_apparent_sidereal_time( &self, tt: Time<Tt>, ut1: Time<Ut1>, corr: Corrections, ) -> GreenwichApparentSiderealTime

Computes Greenwich Apparent Sidereal Time (GAST) for the active IERS convention.

Source

impl ReferenceSystem

pub fn mean_obliquity(&self, time: Time<Tt>) -> MeanObliquity

Returns the mean obliquity of the ecliptic for the given IERS convention.

Source

impl ReferenceSystem

pub fn nutation(&self, time: Time<Tdb>) -> Nutation

Computes nutation for the active IERS convention.

pub fn nutation_matrix(&self, time: Time<Tdb>, corr: Corrections) -> DMat3

Computes the nutation rotation matrix, applying the given corrections.

Source

impl ReferenceSystem

pub fn polar_motion_matrix( &self, time: Time<Tt>, pole_coords: PoleCoords, ) -> DMat3

Returns the polar motion rotation matrix for the given pole coordinates.

Source

impl ReferenceSystem

pub fn precession(&self, time: Time<Tt>) -> PrecessionAngles

Computes the precession angles for the active IERS convention.

pub fn bias_precession_matrix(&self, time: Time<Tt>) -> DMat3

Returns the rotation from ICRF to the Mean-of-Date (MOD) frame for the given IERS convention.

pub fn precession_matrix(&self, time: Time<Tt>) -> DMat3

Returns the precession-only rotation from J2000 to the Mean-of-Date (MOD) frame.

Source

impl ReferenceSystem

pub fn ecliptic_corrections( &self, corr: Corrections, nut: Nutation, epsa: MeanObliquity, rpb: DMat3, ) -> Corrections

Converts EOP corrections between ecliptic and equatorial representations.