pub struct Rotation {
pub m: DMat3,
pub dm: DMat3,
}Expand description
A rotation matrix with its time derivative, for transforming position and velocity vectors.
Fields
m: DMat3Rotation matrix.
dm: DMat3Time derivative of the rotation matrix.
Implementations
Sourceimpl Rotation
impl Rotation
Sourcepub fn with_derivative(self, dm: DMat3) -> Rotation
pub fn with_derivative(self, dm: DMat3) -> Rotation
Sets the time derivative of the rotation matrix.
Sourcepub fn with_angular_velocity(self, v: DVec3) -> Rotation
pub fn with_angular_velocity(self, v: DVec3) -> Rotation
Sets the time derivative from an angular velocity vector.
Sourcepub fn position_matrix(&self) -> DMat3
pub fn position_matrix(&self) -> DMat3
Returns the position rotation matrix.
Sourcepub fn velocity_matrix(&self) -> DMat3
pub fn velocity_matrix(&self) -> DMat3
Returns the velocity rotation matrix (time derivative).
Sourcepub fn compose(self, other: Rotation) -> Rotation
pub fn compose(self, other: Rotation) -> Rotation
Composes this rotation with another (self then other).
Sourcepub fn rotate_position(&self, pos: DVec3) -> DVec3
pub fn rotate_position(&self, pos: DVec3) -> DVec3
Rotates a position vector.
Sourcepub fn rotate_velocity(&self, pos: DVec3, vel: DVec3) -> DVec3
pub fn rotate_velocity(&self, pos: DVec3, vel: DVec3) -> DVec3
Rotates a velocity vector (accounting for the rotation rate).